import { Graph } from '../Graph.js';
export function writeNodeSpecsToJSON(registry) {
    const nodeSpecsJSON = [];
    const graph = new Graph(registry);
    registry.nodes.getAllNames().forEach((nodeTypeName) => {
        const node = graph.createNode(nodeTypeName);
        const nodeSpecJSON = {
            type: nodeTypeName,
            category: node.description.category,
            label: node.description.label,
            inputs: [],
            outputs: []
        };
        node.inputSockets.forEach((inputSocket) => {
            const valueType = inputSocket.valueTypeName === 'flow'
                ? undefined
                : registry.values.get(inputSocket.valueTypeName);
            let defaultValue = inputSocket.value;
            if (valueType !== undefined) {
                defaultValue = valueType.serialize(defaultValue);
            }
            if (defaultValue === undefined && valueType !== undefined) {
                defaultValue = valueType.serialize(valueType.creator());
            }
            const socketSpecJSON = {
                name: inputSocket.name,
                valueType: inputSocket.valueTypeName,
                defaultValue
            };
            nodeSpecJSON.inputs.push(socketSpecJSON);
        });
        node.outputSockets.forEach((outputSocket) => {
            const socketSpecJSON = {
                name: outputSocket.name,
                valueType: outputSocket.valueTypeName
            };
            nodeSpecJSON.outputs.push(socketSpecJSON);
        });
        nodeSpecsJSON.push(nodeSpecJSON);
    });
    return nodeSpecsJSON;
}
//# sourceMappingURL=writeNodeSpecsToJSON.js.map