export function validateGraphAcyclic(graph) {
    Object.values(graph.nodes).forEach((node) => {
        node.metadata['dag.marked'] = 'false';
    });
    const nodesToMark = [];
    do {
        nodesToMark.length = 0;
        Object.values(graph.nodes).forEach((node) => {
            if (node.metadata['dag.marked'] === 'true') {
                return;
            }
            let inputSocketsConnected = false;
            node.inputSockets.forEach((inputSocket) => {
                inputSocket.links.forEach((link) => {
                    if (graph.nodes[link.nodeId].metadata['dag.marked'] === 'false') {
                        inputSocketsConnected = true;
                    }
                });
            });
            if (!inputSocketsConnected) {
                nodesToMark.push(node);
            }
        });
        nodesToMark.forEach((node) => {
            node.metadata['dag.marked'] = 'true';
        });
    } while (nodesToMark.length > 0);
    const errorList = [];
    Object.values(graph.nodes).forEach((node) => {
        if (node.metadata['dag.marked'] === 'false') {
            errorList.push(`node ${node.description.typeName} is part of a cycle, not a directed acyclic graph`);
        }
        delete node.metadata['dag.marked'];
    });
    return errorList;
}
//# sourceMappingURL=validateGraphAcyclic.js.map