export function validateGraphLinks(graph) {
    const errorList = [];
    Object.values(graph.nodes).forEach((node) => {
        node.inputSockets.forEach((inputSocket) => {
            inputSocket.links.forEach((link) => {
                if (!(link.nodeId in graph.nodes)) {
                    errorList.push(`node ${node.description.typeName}.${inputSocket.name} has link using invalid nodeId: ${link.nodeId}`);
                    return;
                }
                const upstreamNode = graph.nodes[link.nodeId];
                const outputSocket = upstreamNode.outputSockets.find((socket) => socket.name === link.socketName);
                if (outputSocket === undefined) {
                    errorList.push(`node ${node.description.typeName}.${inputSocket.name} has link using a non-existent socket name: ` +
                        `${link.socketName}, it can not be found on upstream output node: ${upstreamNode.description.typeName}`);
                    return;
                }
                if (inputSocket.valueTypeName !== outputSocket.valueTypeName) {
                    errorList.push(`type mismatch between ${node.description.typeName}.${inputSocket.name} [${inputSocket.valueTypeName}] ` +
                        `and ${upstreamNode.description.typeName}.${outputSocket.name} [${outputSocket.valueTypeName}]`);
                }
            });
        });
    });
    return errorList;
}
//# sourceMappingURL=validateGraphLinks.js.map