import { EventEmitter } from '../Events/EventEmitter.js';
import { AsyncNode } from './AsyncNode.js';
import { EventNode } from './EventNode.js';
import { FlowNode } from './FlowNode.js';
export class NodeEvalContext {
    constructor(fiber, node, triggeringFlowSocket = undefined) {
        this.fiber = fiber;
        this.node = node;
        this.triggeringFlowSocket = triggeringFlowSocket;
        this.onAsyncCancelled = new EventEmitter();
        this.asyncPending = false;
        this.numCommits = 0;
        this.engine = fiber.engine;
        this.graph = this.engine.graph;
    }
    begin() {
        if (this.node instanceof EventNode) {
            this.engine.eventNodes.push(this.node);
        }
        else if (this.node instanceof AsyncNode) {
            this.engine.asyncNodes.push(this.node);
        }
        else {
            throw new TypeError('unsupported node type');
        }
        this.asyncPending = true;
    }
    cancel() {
        this.onAsyncCancelled.emit();
        this.finish();
    }
    finish() {
        if (this.node instanceof EventNode) {
            const index = this.engine.eventNodes.indexOf(this.node);
            this.engine.eventNodes.splice(index, 1);
        }
        else if (this.node instanceof AsyncNode) {
            const index = this.engine.asyncNodes.indexOf(this.node);
            this.engine.asyncNodes.splice(index, 1);
        }
        else {
            throw new TypeError('unsupported node type');
        }
    }
    evalFlow() {
        const flowNode = this.node;
        if (!(flowNode instanceof FlowNode)) {
            throw new TypeError('node must be instance of FlowNode');
        }
        const isAsync = flowNode instanceof AsyncNode;
        if (isAsync) {
            this.begin();
        }
        this.engine.onNodeExecution.emit(flowNode);
        flowNode.exec(this.fiber);
    }
}
//# sourceMappingURL=NodeEvalContext.js.map