export class NodeTypeRegistry {
    constructor() {
        this.typeNameToNodeDescriptions = {};
    }
    clear() {
        for (const nodeTypeName in this.typeNameToNodeDescriptions) {
            delete this.typeNameToNodeDescriptions[nodeTypeName];
        }
    }
    register(...descriptions) {
        descriptions.forEach((description) => {
            if (description.typeName in this.typeNameToNodeDescriptions) {
                throw new Error(`already registered node type ${description.typeName} (string)`);
            }
            this.typeNameToNodeDescriptions[description.typeName] = description;
        });
    }
    contains(typeName) {
        return typeName in this.typeNameToNodeDescriptions;
    }
    get(typeName) {
        if (!(typeName in this.typeNameToNodeDescriptions)) {
            throw new Error(`no registered node with type name ${typeName}`);
        }
        return this.typeNameToNodeDescriptions[typeName];
    }
    getAllNames() {
        return Object.keys(this.typeNameToNodeDescriptions);
    }
    getAllDescriptions() {
        return Object.values(this.typeNameToNodeDescriptions);
    }
}
//# sourceMappingURL=NodeTypeRegistry.js.map