import { Node } from '../../../Nodes/Node.js';
import { Socket } from '../../../Sockets/Socket.js';
export class OnLifecycleTick extends Node {
    constructor() {
        super('Event', 'lifecycle/tick', [], [
            new Socket('flow', 'flow'),
            new Socket('float', 'deltaSeconds'),
            new Socket('float', 'time')
        ], (context) => {
            let lastTickTime = Date.now();
            const onTickEvent = () => {
                const currentTime = Date.now();
                const deltaSeconds = (currentTime - lastTickTime) * 0.001;
                context.writeOutput('deltaSeconds', deltaSeconds);
                context.writeOutput('time', Date.now());
                context.commit('flow');
                lastTickTime = currentTime;
            };
            const lifecycleEvents = context.graph.registry.implementations.get('ILifecycleEventEmitter');
            lifecycleEvents.tickEvent.addListener(onTickEvent);
            context.onAsyncCancelled.addListener(() => {
                lifecycleEvents.tickEvent.removeListener(onTickEvent);
            });
        });
        this.async = true;
        this.evaluateOnStartup = true;
        this.interruptibleAsync = true;
    }
}
//# sourceMappingURL=OnLifecycleTick.js.map