import { Assert } from '../../../Diagnostics/Assert.js';
import { EventNode } from '../../../Nodes/EventNode.js';
import { NodeDescription } from '../../../Nodes/Registry/NodeDescription.js';
import { Socket } from '../../../Sockets/Socket.js';
export class LifecycleOnEnd extends EventNode {
    constructor(description, graph, lifecycleEventEmitter) {
        super(description, graph, [], [new Socket('flow', 'flow')]);
        this.lifecycleEventEmitter = lifecycleEventEmitter;
        this.onEndEvent = undefined;
    }
    init(engine) {
        Assert.mustBeTrue(this.onEndEvent === undefined);
        this.onEndEvent = () => {
            engine.commitToNewFiber(this, 'flow');
        };
        this.lifecycleEventEmitter.endEvent.addListener(this.onEndEvent);
    }
    dispose(engine) {
        Assert.mustBeTrue(this.onEndEvent !== undefined);
        if (this.onEndEvent !== undefined) {
            this.lifecycleEventEmitter.endEvent.removeListener(this.onEndEvent);
        }
    }
}
LifecycleOnEnd.Description = (lifecycleEventEmitter) => new NodeDescription('lifecycle/onEnd', 'Event', 'On End', (description, graph) => new LifecycleOnEnd(description, graph, lifecycleEventEmitter));
//# sourceMappingURL=LifecycleOnEnd.js.map