import { Assert } from '../../../Diagnostics/Assert.js';
import { EventNode } from '../../../Nodes/EventNode.js';
import { NodeDescription } from '../../../Nodes/Registry/NodeDescription.js';
import { Socket } from '../../../Sockets/Socket.js';
export class LifecycleOnStart extends EventNode {
    constructor(description, graph, lifecycleEventEmitter) {
        super(description, graph, [], [new Socket('flow', 'flow')]);
        this.lifecycleEventEmitter = lifecycleEventEmitter;
        this.onStartEvent = undefined;
    }
    init(engine) {
        Assert.mustBeTrue(this.onStartEvent === undefined);
        this.onStartEvent = () => {
            engine.commitToNewFiber(this, 'flow');
        };
        this.lifecycleEventEmitter.startEvent.addListener(this.onStartEvent);
    }
    dispose(engine) {
        Assert.mustBeTrue(this.onStartEvent !== undefined);
        if (this.onStartEvent !== undefined) {
            this.lifecycleEventEmitter.startEvent.removeListener(this.onStartEvent);
        }
    }
}
LifecycleOnStart.Description = (lifecycleEventEmitter) => new NodeDescription('lifecycle/onStart', 'Event', 'On Start', (description, graph) => new LifecycleOnStart(description, graph, lifecycleEventEmitter));
//# sourceMappingURL=LifecycleOnStart.js.map