import { In1Out1FuncNode } from '../../Nodes/Templates/In1Out1FuncNode.js';
import { In2Out1FuncNode } from '../../Nodes/Templates/In2Out1FuncNode.js';
import { In3Out1FuncNode } from '../../Nodes/Templates/In3Out1FuncNode.js';
import { ValueType } from '../../Values/ValueType.js';
import { VecCreate } from './Logic/VecCreate.js';
import { VecElements } from './Logic/VecElements.js';
import { hexToRGB, hslToRGB, rgbToHex, rgbToHSL, Vec3, vec3Add, vec3FromArray, vec3Mix, vec3Parse, vec3Scale, vec3Subtract, vec3ToArray, vec3ToString } from './Values/Vec3.js';
export function registerColorValue(registry) {
    const { nodes, values } = registry;
    values.register(new ValueType('color', () => new Vec3(), (value) => typeof value === 'string'
        ? vec3Parse(value)
        : new Vec3(value.r, value.g, value.b), (value) => ({ r: value.x, g: value.y, b: value.z })));
    nodes.register('logic/create/color', () => new VecCreate('logic/create/color', 'color', ['r', 'g', 'b'], (elements) => vec3FromArray(elements)));
    nodes.register('logic/color', () => new In1Out1FuncNode('logic/color', 'color', 'color', (a) => a));
    nodes.register('logic/elements/color', () => new VecElements('logic/elements/color', 'color', ['r', 'g', 'b'], vec3ToArray));
    nodes.register('logic/add/color', () => new In2Out1FuncNode('logic/add/color', 'color', 'color', 'color', (a, b) => vec3Add(a, b)));
    nodes.register('logic/toString/color', () => new In1Out1FuncNode('logic/toString/color', 'color', 'string', (a) => vec3ToString(a)));
    nodes.register('logic/subtract/color', () => new In2Out1FuncNode('logic/subtract/color', 'color', 'color', 'color', (a, b) => vec3Subtract(a, b)));
    nodes.register('logic/scale/color', () => new In2Out1FuncNode('logic/scale/color', 'color', 'float', 'color', (a, b) => vec3Scale(a, b)));
    nodes.register('logic/mix/color', () => new In3Out1FuncNode('logic/mix/color', 'color', 'color', 'float', 'color', (a, b, c) => vec3Mix(a, b, c)));
    nodes.register('logic/hslToColor', () => new In1Out1FuncNode('logic/hslToColor', 'vec3', 'color', (a) => hslToRGB(a)));
    nodes.register('logic/colorToHSL', () => new In1Out1FuncNode('logic/colorToHSL', 'color', 'vec3', (a) => rgbToHSL(a)));
    nodes.register('logic/colorToHex', () => new In1Out1FuncNode('logic/colorToHex', 'color', 'float', (a) => rgbToHex(a)));
    nodes.register('logic/hexToColor', () => new In1Out1FuncNode('logic/hexToColor', 'float', 'color', (a) => hexToRGB(a)));
}
//# sourceMappingURL=registerColorValue.js.map