import { In1Out1FuncNode } from '../../Nodes/Templates/In1Out1FuncNode.js';
import { In2Out1FuncNode } from '../../Nodes/Templates/In2Out1FuncNode.js';
import { In3Out1FuncNode } from '../../Nodes/Templates/In3Out1FuncNode.js';
import { ValueType } from '../../Values/ValueType.js';
import { VecCreate } from './Logic/VecCreate.js';
import { VecElements } from './Logic/VecElements.js';
import { Vec4, vec4Add, vec4Dot, vec4FromArray, vec4Length, vec4Mix, vec4Normalize, vec4Parse, vec4Scale, vec4Subtract, vec4ToArray, vec4ToString } from './Values/Vec4.js';
export function registerVec4Value(registry) {
    const { nodes, values } = registry;
    values.register(new ValueType('vec4', () => new Vec4(), (value) => typeof value === 'string'
        ? vec4Parse(value)
        : new Vec4(value.x, value.y, value.z, value.w), (value) => ({ x: value.x, y: value.y, z: value.z, w: value.w })));
    nodes.register('logic/create/vec4', () => new VecCreate('logic/create/vec4', 'vec4', ['x', 'y', 'z', 'w'], (elements) => vec4FromArray(elements)));
    nodes.register('logic/vec4', () => new In1Out1FuncNode('logic/vec4', 'vec4', 'vec4', (a) => a));
    nodes.register('logic/elements/vec4', () => new VecElements('logic/elements/vec4', 'vec4', ['x', 'y', 'z', 'w'], vec4ToArray));
    nodes.register('logic/scale/vec4', () => new In2Out1FuncNode('logic/scale/vec4', 'vec4', 'float', 'vec4', (a, b) => vec4Scale(a, b)));
    nodes.register('logic/subtract/vec4', () => new In2Out1FuncNode('logic/subtract/vec4', 'vec4', 'vec4', 'vec4', (a, b) => vec4Subtract(a, b)));
    nodes.register('logic/add/vec4', () => new In2Out1FuncNode('logic/add/vec4', 'vec4', 'vec4', 'vec4', (a, b) => vec4Add(a, b)));
    nodes.register('logic/mix/vec4', () => new In3Out1FuncNode('logic/mix/vec4', 'vec4', 'vec4', 'float', 'vec4', (a, b, c) => vec4Mix(a, b, c)));
    nodes.register('logic/dot/vec4', () => new In2Out1FuncNode('logic/dot/vec4', 'vec4', 'vec4', 'float', (a, b) => vec4Dot(a, b)));
    nodes.register('logic/normalize/vec4', () => new In1Out1FuncNode('logic/normalize/vec4', 'vec4', 'vec4', (a) => vec4Normalize(a)));
    nodes.register('logic/length/vec4', () => new In1Out1FuncNode('logic/length/vec4', 'vec4', 'float', (a) => vec4Length(a)));
    nodes.register('logic/toString/vec4', () => new In1Out1FuncNode('logic/toString/vec4', 'vec4', 'string', (a) => vec4ToString(a)));
}
//# sourceMappingURL=registerVec4Value.js.map