import { parseFloats } from '../../../parseFloats';
export class Vec2 {
    constructor(x = 0, y = 0) {
        this.x = x;
        this.y = y;
    }
    clone(optionalResult = new Vec2()) {
        return optionalResult.set(this.x, this.y);
    }
    set(x, y) {
        this.x = x;
        this.y = y;
        return this;
    }
}
export function vec2Equals(a, b) {
    return a.x === b.x && a.y === b.y;
}
export function vec2Add(a, b, optionalResult = new Vec2()) {
    return optionalResult.set(a.x + b.x, a.y + b.y);
}
export function vec2Subtract(a, b, optionalResult = new Vec2()) {
    return optionalResult.set(a.x - b.x, a.y - b.y);
}
export function vec2Scale(a, b, optionalResult = new Vec2()) {
    return optionalResult.set(a.x * b, a.y * b);
}
export function vec2Negate(a, optionalResult = new Vec2()) {
    return optionalResult.set(-a.x, -a.y);
}
export function vec2Length(a) {
    return Math.sqrt(vec2Dot(a, a));
}
export function vec2Normalize(a, optionalResult = new Vec2()) {
    const invLength = 1 / vec2Length(a);
    return vec2Scale(a, invLength, optionalResult);
}
export function vec2Dot(a, b) {
    return a.x * b.x + a.y * b.y;
}
export function vec2Mix(a, b, t, optionalResult = new Vec2()) {
    const s = 1 - t;
    return optionalResult.set(a.x * s + b.x * t, a.y * s + b.y * t);
}
export function vec2FromArray(array, offset = 0, optionalResult = new Vec2()) {
    return optionalResult.set(array[offset + 0], array[offset + 1]);
}
export function vec2ToArray(a, array, offset = 0) {
    array[offset + 0] = a.x;
    array[offset + 1] = a.y;
}
export function vec2ToString(a) {
    return `(${a.x}, ${a.y})`;
}
export function vec2Parse(text, optionalResult = new Vec2()) {
    return vec2FromArray(parseFloats(text), 0, optionalResult);
}
//# sourceMappingURL=Vec2.js.map