import { In1Out1FuncNode } from '../../Nodes/Templates/In1Out1FuncNode';
import { In2Out1FuncNode } from '../../Nodes/Templates/In2Out1FuncNode';
import { In3Out1FuncNode } from '../../Nodes/Templates/In3Out1FuncNode';
import { ValueType } from '../../Values/ValueType';
import { SetVariable } from '../Core/Actions/SetVariable';
import { OnVariableChanged } from '../Core/Events/OnVariableChanged';
import { GetVariable } from '../Core/Queries/GetVariable';
import { SetSceneNodeProperty } from './Actions/SetSceneNodeProperty';
import { OnSceneNodeClick } from './Events/OnSceneNodeClick';
import { Vec2Create } from './Logic/Vec2Create';
import { Vec2Elements } from './Logic/Vec2Elements';
import { Vec3Create } from './Logic/Vec3Create';
import { Vec3Elements } from './Logic/Vec3Elements';
import { Vec4Create } from './Logic/Vec4Create';
import { Vec4Elements } from './Logic/Vec4Elements';
import { GetSceneNodeProperty } from './Queries/GetSceneNodeProperty';
import { Vec2, vec2Add, vec2Length, vec2Negate, vec2Normalize, vec2Parse, vec2Scale, vec2Subtract, vec2ToString } from './Values/Vec2';
import { Vec3, vec3Add, vec3Cross, vec3Dot, vec3Length, vec3Negate, vec3Normalize, vec3Parse, vec3Scale, vec3Subtract, vec3ToString } from './Values/Vec3';
import { quatConjugate, quatMultiply, quatSlerp, Vec4, vec4Dot, vec4Length, vec4Normalize, vec4Parse, vec4ToString } from './Values/Vec4';
export function registerSceneGraphProfile(registry) {
    const { values, nodes } = registry;
    values.register(new ValueType('vec2', () => new Vec2(), (text) => vec2Parse(text), (value) => vec2ToString(value)));
    values.register(new ValueType('vec3', () => new Vec3(), (text) => vec3Parse(text), (value) => vec3ToString(value)));
    values.register(new ValueType('vec4', () => new Vec4(), (text) => vec4Parse(text), (value) => vec4ToString(value)));
    nodes.register('event/nodeClick', () => new OnSceneNodeClick());
    nodes.register('action/setSceneNodeBoolean', () => new SetSceneNodeProperty('action/setSceneNodeBoolean', 'boolean'));
    nodes.register('action/setSceneNodeNumber', () => new SetSceneNodeProperty('action/setSceneNodeNumber', 'float'));
    nodes.register('action/setSceneNodeVec2', () => new SetSceneNodeProperty('action/setSceneNodeVec2', 'vec2'));
    nodes.register('action/setSceneNodeVec3', () => new SetSceneNodeProperty('action/setSceneNodeVec3', 'vec3'));
    nodes.register('action/setSceneNodeVec4', () => new SetSceneNodeProperty('action/setSceneNodeVec4', 'vec4'));
    nodes.register('query/getSceneNodeBoolean', () => new GetSceneNodeProperty('query/getSceneNodeBoolean', 'boolean'));
    nodes.register('query/getSceneNodeNumber', () => new GetSceneNodeProperty('query/getSceneNodeNumber', 'float'));
    nodes.register('query/getSceneNodeVec2', () => new GetSceneNodeProperty('query/getSceneNodeVec2', 'vec2'));
    nodes.register('query/getSceneNodeVec3', () => new GetSceneNodeProperty('query/getSceneNodeVec3', 'vec3'));
    nodes.register('query/getSceneNodeVec4', () => new GetSceneNodeProperty('query/getSceneNodeVec4', 'vec4'));
    nodes.register('logic/vec2Create', () => new Vec2Create());
    nodes.register('logic/vec2Elements', () => new Vec2Elements());
    nodes.register('logic/vec2Add', () => new In2Out1FuncNode('logic/vec2Add', 'vec2', 'vec2', 'vec2', (a, b) => vec2Add(a, b)));
    nodes.register('logic/vec2Subtract', () => new In2Out1FuncNode('logic/vec2Subtract', 'vec2', 'vec2', 'vec2', (a, b) => vec2Subtract(a, b)));
    nodes.register('logic/vec2Scale', () => new In2Out1FuncNode('logic/vec2Scale', 'vec2', 'float', 'vec2', (a, b) => vec2Scale(a, b)));
    nodes.register('logic/vec2Negate', () => new In1Out1FuncNode('logic/vec2Negate', 'vec2', 'vec2', (a) => vec2Negate(a)));
    nodes.register('logic/vec2Normalize', () => new In1Out1FuncNode('logic/vec2Normalize', 'vec2', 'vec2', (a) => vec2Normalize(a)));
    nodes.register('logic/vec2Length', () => new In1Out1FuncNode('logic/vec2Length', 'vec2', 'float', (a) => vec2Length(a)));
    nodes.register('logic/vec2ToString', () => new In1Out1FuncNode('logic/vec2ToString', 'vec2', 'string', (a) => vec2ToString(a)));
    nodes.register('logic/vec3Create', () => new Vec3Create());
    nodes.register('logic/vec3Elements', () => new Vec3Elements());
    nodes.register('logic/vec3Add', () => new In2Out1FuncNode('logic/vec3Add', 'vec3', 'vec3', 'vec3', (a, b) => vec3Add(a, b)));
    nodes.register('logic/vec3Subtract', () => new In2Out1FuncNode('logic/vec3Subtract', 'vec3', 'vec3', 'vec3', (a, b) => vec3Subtract(a, b)));
    nodes.register('logic/vec3Scale', () => new In2Out1FuncNode('logic/vec3Scale', 'vec3', 'float', 'vec3', (a, b) => vec3Scale(a, b)));
    nodes.register('logic/vec3Cross', () => new In2Out1FuncNode('logic/vec3Cross', 'vec3', 'vec3', 'vec3', (a, b) => vec3Cross(a, b)));
    nodes.register('logic/vec3Dot', () => new In2Out1FuncNode('logic/vec3Dot', 'vec3', 'vec3', 'float', (a, b) => vec3Dot(a, b)));
    nodes.register('logic/vec3Negate', () => new In1Out1FuncNode('logic/vec3Negate', 'vec3', 'vec3', (a) => vec3Negate(a)));
    nodes.register('logic/vec3Normalize', () => new In1Out1FuncNode('logic/vec3Normalize', 'vec3', 'vec3', (a) => vec3Normalize(a)));
    nodes.register('logic/vec3Length', () => new In1Out1FuncNode('logic/vec3Length', 'vec3', 'float', (a) => vec3Length(a)));
    nodes.register('logic/vec3ToString', () => new In1Out1FuncNode('logic/vec3ToString', 'vec3', 'string', (a) => vec3ToString(a)));
    nodes.register('logic/vec4Create', () => new Vec4Create());
    nodes.register('logic/vec4Elements', () => new Vec4Elements());
    nodes.register('logic/quatMultiply', () => new In2Out1FuncNode('logic/quatMultiply', 'vec4', 'vec4', 'vec4', (a, b) => quatMultiply(a, b)));
    nodes.register('logic/vec4Dot', () => new In2Out1FuncNode('logic/vec4Dot', 'vec4', 'vec4', 'float', (a, b) => vec4Dot(a, b)));
    nodes.register('logic/quatConjugate', () => new In1Out1FuncNode('logic/quatConjugate', 'vec4', 'vec4', (a) => quatConjugate(a)));
    nodes.register('logic/quatSlerp', () => new In3Out1FuncNode('logic/quatSlerp', 'vec4', 'vec4', 'float', 'vec4', (a, b, c) => quatSlerp(a, b, c)));
    nodes.register('logic/vec4Normalize', () => new In1Out1FuncNode('logic/vec4Normalize', 'vec4', 'vec4', (a) => vec4Normalize(a)));
    nodes.register('logic/vec4Length', () => new In1Out1FuncNode('logic/vec4Length', 'vec4', 'float', (a) => vec4Length(a)));
    nodes.register('logic/vec4ToString', () => new In1Out1FuncNode('logic/vec4ToString', 'vec4', 'string', (a) => vec4ToString(a)));
    nodes.register('variable/setVec2', () => new SetVariable('variable/setVec2', 'vec2'));
    nodes.register('variable/getVec2', () => new GetVariable('variable/getVec2', 'vec2'));
    nodes.register('variable/onVec2Changed', () => new OnVariableChanged('variable/onVec2Changed', 'vec2'));
    nodes.register('variable/setVec3', () => new SetVariable('variable/setVec3', 'vec3'));
    nodes.register('variable/getVec3', () => new GetVariable('variable/getVec3', 'vec3'));
    nodes.register('variable/onVec3Changed', () => new OnVariableChanged('variable/onVec3Changed', 'vec3'));
    nodes.register('variable/setVec4', () => new SetVariable('variable/setVec4', 'vec4'));
    nodes.register('variable/getVec4', () => new GetVariable('variable/getVec4', 'vec4'));
    nodes.register('variable/onVec4Changed', () => new OnVariableChanged('variable/onVec4Changed', 'vec4'));
    return registry;
}
//# sourceMappingURL=registerSceneGraphProfile.js.map